==> rc-ui-lib-0.1.41.tgz: package/es/button/__test__/index.spec.js <==
import React from 'react';
import { mount } from 'enzyme';
import Button from '../index';
import mountTest from '../../../tests/shared/mountTest';
describe('Button', function () {
  mountTest(Button);
  mountTest(function () {
    return /*#__PURE__*/React.createElement(Button, {
      type: "primary"
    });
  });
  it('renders correctly', function () {
    expect( /*#__PURE__*/React.createElement(Button, null)).toMatchRenderedSnapshot();
  });
  it('mount correctly', function () {
    expect(function () {
      return mount( /*#__PURE__*/React.createElement(Button, null));
    }).not.toThrow();
  });
  it('should render empty button without errors', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, null, null, undefined));
    expect(wrapper.render()).toMatchSnapshot();
  });
  it('should simulate click event', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, null));
    expect(wrapper.simulate('click').length).toEqual(1);
  });
  it('should not emit click event when disabled', function () {
    var onClick = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      disabled: true,
      onClick: onClick
    }));
    wrapper.simulate('click');
    expect(onClick).not.toHaveBeenCalled();
  });
  it('should hide border when color is gradient', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      color: "linear-gradient(#000, #fff)"
    }));
    expect(wrapper.getDOMNode().style.border).toEqual('0px');
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      icon: "success",
      iconPrefix: "my-icon"
    }));
    expect(wrapper.html()).toMatchSnapshot();
  });
});

==> rc-ui-lib-0.2.4.tgz: package/es/button/__test__/index.spec.js <==
import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Icon from '../../icon';
import Button from '..';
describe('Button', function () {
  it('renders correctly', function () {
    expect( /*#__PURE__*/React.createElement(Button, null)).toMatchRenderedSnapshot();
  });
  it('mount correctly', function () {
    expect(function () {
      return mount( /*#__PURE__*/React.createElement(Button, null));
    }).not.toThrow();
  });
  it('should render empty button without errors', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, null, null, undefined));
    expect(wrapper.render()).toMatchSnapshot();
  });
  it('should simulate click event', function () {
    var onClick = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      onClick: onClick
    }));
    wrapper.simulate('click');
    expect(onClick).toHaveBeenCalledTimes(1);
  });
  it('should not emit click event when disabled', function () {
    var onClick = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      disabled: true,
      onClick: onClick
    }));
    wrapper.simulate('click');
    expect(onClick).not.toHaveBeenCalled();
  });
  it('should render correctly when loading prop is set', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      type: "primary",
      loading: true
    }));
    expect(wrapper.find('.rc-loading__spinner').exists()).toBeTruthy();
  });
  it('should hide border when color is gradient', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      color: "linear-gradient(#000, #fff)"
    }));
    expect(wrapper.getDOMNode().style.border).toEqual('0px');
  });
  it('should hide border when color is not gradient', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      type: "primary",
      color: "red"
    }));
    expect(wrapper.getDOMNode().style.borderColor).toEqual('red');
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      icon: "success",
      iconPrefix: "my-icon"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render correctly when icon is JSX element', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      icon: /*#__PURE__*/React.createElement(Icon, {
        name: "shop-o"
      })
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
  it('should render iconPosition correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      type: "primary",
      iconPosition: "right"
    }));
    expect(wrapper.find('.rc-loading__spinner').exists()).toBeFalsy();
  });
  it('should render buttton group correctly', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button.Group, null, /*#__PURE__*/React.createElement(Button, {
      type: "primary"
    }, "next step")));
    expect(wrapper.find('.rc-button-group').exists()).toBeTruthy();
    expect(toJson(wrapper)).toMatchSnapshot();
  });
});
